@@ -1,15 +1,8 @@
-# import pydicom
-# import SimpleITK as sitk
-import CIRS_063
+from cirs_063 import CIRS_063
 import constants as C
 from tqdm import tqdm
-# import matplotlib.pyplot as plt
 import numpy as np
 np.seterr(all='ignore')
-# import os
-# import sitktools
-# from Phantom_analysis_toolbox import Phantom_analysis_toolbox as pat
-# import math
     
 
 def main():    
